@@ -13,7 +13,7 @@ from microbiome.helpers import df2vectors
 from microbiome.trajectory import plot_1_trajectory
 from matplotlib.ticker import MaxNLocator
 import plotly.graph_objects as go
-
+from plotly.tools import mpl_to_plotly
 
 def get_top_bacteria_in_time(estimator, df_all, top_bacteria, days_start, days_number_1unit, num_top_bacteria, average=np.median, std=np.std, time_unit_size=1, time_unit_name="days"):  # scipy.stats.hmean
     """
@@ -67,7 +67,7 @@ def get_top_bacteria_in_time(estimator, df_all, top_bacteria, days_start, days_n
 
 def plot_importance_boxplots_over_age(estimator, df_all, top_bacteria, nice_name, units, num_top_bacteria=5, start_age=0, limit_age=None, patent=False, highlight_outliers=None, df_new=None, 
                                         time_unit_size=1, time_unit_name="days", box_height=None, img_file_name=None, plateau_area_start=None, longitudinal_mode="markers+lines", longitudinal_showlegend=True, 
-                                        fillcolor_alpha=0.3, layout_settings=None, website=False):
+                                        fillcolor_alpha=0.3, layout_settings=None, website=False, PI_percentage=90, dtick=2):
     
     df = df_all.copy()
     
@@ -84,6 +84,7 @@ def plot_importance_boxplots_over_age(estimator, df_all, top_bacteria, nice_name
     df["y"] = y
     df["y_pred"] = y_pred
 
+
     if df_new is not None:
         X, y = df2vectors(df_new, top_bacteria)
         y_pred = estimator.predict(X)
@@ -135,7 +136,7 @@ def plot_importance_boxplots_over_age(estimator, df_all, top_bacteria, nice_name
     fig, ret_val, mae, r2, pi_median, traj_x, traj_pi, traj_mean = plot_1_trajectory(fig, estimator, df, top_bacteria, limit_age_max, time_unit_size, time_unit_name, traj_color=traj_color, traj_label="reference", 
                                                                    plateau_area_start=plateau_area_start, limit_age_max=limit_age_max, longitudinal_mode=longitudinal_mode, 
                                                                    longitudinal_showlegend=longitudinal_showlegend, fillcolor_alpha=fillcolor_alpha, highlight_outliers=highlight_outliers,
-                                                                  marker_outlier=marker_outlier, df_new=df_new, plot_CI=False, plot_PI=True)
+                                                                  marker_outlier=marker_outlier, df_new=df_new, plot_CI=False, plot_PI=True, PI_percentage=PI_percentage)
 
     if box_height is None:
         box_height = 2*np.median(traj_pi)
@@ -188,11 +189,11 @@ def plot_importance_boxplots_over_age(estimator, df_all, top_bacteria, nice_name
     fig.update_xaxes( 
         title=f"Age [{time_unit_name}]",
         range=(0, latest_day/time_unit_size),
-        tick0=start_age/time_unit_size, dtick=2,
+        tick0=start_age/time_unit_size, dtick=dtick,
         showline=True, linecolor='lightgrey', gridcolor='lightgrey', zeroline=True, zerolinecolor='lightgrey')
     fig.update_yaxes(
         title=f"Microbiome Maturation Index [{time_unit_name}]",
-        tick0=start_age/time_unit_size, dtick=2,
+        tick0=start_age/time_unit_size, dtick=dtick,
         range=(0, latest_day/time_unit_size), 
         showline=True, linecolor='lightgrey', gridcolor='lightgrey') 
 
@@ -263,7 +264,25 @@ def outlier_intervention(outlier_sampleID, estimator, df_all, feature_columns, n
     if plot:
         shap.force_plot(explainer.expected_value, shap_values[i], features=X[i], feature_names=feature_columns_short, text_rotation=90, matplotlib=True)
         plt.show()
-    
+    else:
+        fig1, ax = plt.subplots()
+        shap.force_plot(explainer.expected_value, shap_values[i], features=X[i], feature_names=feature_columns_short, text_rotation=90, matplotlib=plot)
+        
+        fig1 =  mpl_to_plotly(fig1)
+            
+        fig1.update_xaxes(title="SHAP value (impact on model output)", 
+                        showline=True, linecolor='lightgrey', gridcolor='lightgrey', zeroline=True, zerolinecolor='lightgrey', showspikes=True, spikecolor='gray') 
+        fig1.update_yaxes(title="Features", 
+                            tickmode='array',
+                            tickvals=list(range(0, min(20, len(feature_columns_short)))),  #list(X_train.columns[np.argsort(np.abs(shap_values[0]).mean(0))])[::-1][:min(20, len(feature_names))], # 
+                            #ticktext=list(map(nice_name, list(X_train.columns[np.argsort(np.abs(shap_values[0]).mean(0))])[::-1][:min(20, len(feature_names))][::-1])),
+                        showline=True, linecolor='lightgrey', gridcolor='lightgrey', zeroline=True, zerolinecolor='lightgrey', showspikes=True, spikecolor='gray')  
+        fig1.update_layout(#height=layout_height, width=layout_width,
+                        #paper_bgcolor="white",#'rgba(0,0,0,0)', 
+                        plot_bgcolor='rgba(0,0,0,0)', 
+                        margin=dict(l=0, r=0, b=0, pad=0),
+                        title_text="Classification Important Features")
+
     ### Intervention Table ###
     # get importances of outlier
     feature_importance_outlier = pd.DataFrame(list(zip(feature_columns, np.abs(shap_values).mean(0))), columns=['bacteria_name','feature_importance_outlier'])
@@ -275,6 +294,7 @@ def outlier_intervention(outlier_sampleID, estimator, df_all, feature_columns, n
                                                                        days_number_1unit=(left+right)*time_unit_size, 
                                                                        num_top_bacteria=5, 
                                                                        average=average, std=std)
+    print(feature_importance)
     #display(feature_importance)
     # merge two importances
     feature_importance["outlier"] = feature_importance.apply(lambda x: df_all.iloc[i][x["bacteria_name"]], axis=1)
@@ -329,7 +349,25 @@ def outlier_intervention(outlier_sampleID, estimator, df_all, feature_columns, n
     if plot:
         shap.force_plot(explainer.expected_value, shap_values[i], features=X[i], feature_names=feature_columns_short, text_rotation=90, matplotlib=True)
         plt.show()
+    else:
 
+        fig2, ax = plt.subplots()
+        shap.force_plot(explainer.expected_value, shap_values[i], features=X[i], feature_names=feature_columns_short, text_rotation=90, matplotlib=plot)
+        
+        fig2 =  mpl_to_plotly(fig2)
+            
+        fig2.update_xaxes(title="SHAP value (impact on model output)", 
+                        showline=True, linecolor='lightgrey', gridcolor='lightgrey', zeroline=True, zerolinecolor='lightgrey', showspikes=True, spikecolor='gray') 
+        fig2.update_yaxes(title="Features", 
+                            tickmode='array',
+                            tickvals=list(range(0, min(20, len(feature_columns_short)))),  #list(X_train.columns[np.argsort(np.abs(shap_values[0]).mean(0))])[::-1][:min(20, len(feature_names))], # 
+                            #ticktext=list(map(nice_name, list(X_train.columns[np.argsort(np.abs(shap_values[0]).mean(0))])[::-1][:min(20, len(feature_names))][::-1])),
+                        showline=True, linecolor='lightgrey', gridcolor='lightgrey', zeroline=True, zerolinecolor='lightgrey', showspikes=True, spikecolor='gray')  
+        fig2.update_layout(#height=layout_height, width=layout_width,
+                        #paper_bgcolor="white",#'rgba(0,0,0,0)', 
+                        plot_bgcolor='rgba(0,0,0,0)', 
+                        margin=dict(l=0, r=0, b=0, pad=0),
+                        title_text="Classification Important Features")
     
     
-    return df_all_updated
\ No newline at end of file
+    return df_all_updated, fig1, fig2, ret_val1+ret_val2+ret_val3
\ No newline at end of file
